#
# Cookbook Name:: ziggrid
# Recipe:: ziggrid
#
# Copyright (C) 2013 Ziniki Infrastructure Software, LLC.
# 

include_recipe "ziggrid::shared"

bluepill_service 'ziggrid' do
  action :stop
end

# download ziggrid prod file only if it isn't already on the target system
local_static_file = File.join(Chef::Config[:file_cache_path], node[:ziggrid][:static][:filename])

#ziggrid static
remote_file local_static_file do
  source "#{node[:ziggrid][:static][:base_url]}/#{node[:ziggrid][:static][:filename]}"
  owner node[:ziggrid][:user]
  group node[:ziggrid][:group]
  mode "0755"
  action :create
end

deployDir = node[:ziggrid][:deploy_dir]

%w{metrics}.each do |dir|
  directory File.join(deployDir, dir) do
    mode 0755
    owner node[:ziggrid][:user]
    group node[:ziggrid][:group]
    action :create
    recursive true
  end
end

#configure log4j.properties
template File.join(deployDir, "logs", "ziggrid-log4j.properties") do
  source "log4j.properties.erb"
  owner node[:ziggrid][:user]
  group node[:ziggrid][:group]
  mode 0644
  variables({
    :logFile           => File.join(deployDir, "logs", "ziggrid.log"),
  })
end

execute "extract #{local_static_file}" do
  command "unzip -q -u -o #{local_static_file} -d #{deployDir}"
  user    node[:ziggrid][:user]
  group   node[:ziggrid][:group]
end

#download each file defined on the config zip list and expand them to the config directory
node[:ziggrid][:model][:zip_file_list].each do |config_zip|
  
  config_zip_full_path = File.join(Chef::Config[:file_cache_path], config_zip)

  remote_file config_zip_full_path do
    source "#{node[:ziggrid][:model][:base_url]}/#{config_zip}"
    owner node[:ziggrid][:user]
    group node[:ziggrid][:group]
    mode "0755"
    action :create
  end

  execute "extract #{config_zip_full_path}" do
    command "unzip -q -u -o #{config_zip_full_path} -d #{deployDir}/config"
    user    node[:ziggrid][:user]
    group   node[:ziggrid][:group]
  end

end

debugArguments = ""
if node[:ziggrid][:debug]
  Chef::Log.info "Putting debug arguments into cluster startup command"
  debugArguments = "-Xdebug -Xrunjdwp:server=y,transport=dt_socket,address=4026,suspend=n"
end

java_command_array = [  
  "java",
  "-cp 'libs/*'",
  debugArguments,
  "-Dlog4j.debug",
  "-Dlog4j.configuration=file:/opt/ziggrid/logs/ziggrid-log4j.properties",
  "-Dorg.ziniki.claim.endpoint=#{node[:ec2][:public_hostname]}",
  "-Djava.util.logging.config.class=com.gmmapowell.utils.http.LoggingConfiguration",
  "-Dnet.spy.log.LoggerImpl=net.spy.memcached.compat.log.Log4JLogger",
  "org.ziggrid.driver.Ziggrid",                         
  node[:ziggrid][:couchbase][:url],
  "#{deployDir}/config",
  node[:ziggrid][:collect_metrics] ? "--metricsDir #{File.join(deployDir, "metrics")}" : "",
  # consider case of non trailblazer zinikicouch
  "--connector org.ziggrid.driver.RawTapMessageSource #{node[:zinikicouch][:trailblazer][:domain_name]} #{node[:ziggrid][:bucket_name]}",
  #"--connector org.ziggrid.driver.QueueMessageSource #{node.run_state['zigtaptomq_ip']} tap",
  "--connector org.ziggrid.driver.WebServer #{deployDir} #{node[:ziggrid][:webserver][:port]}",
]

java_command = java_command_array.join(' ')

Chef::Log.info "Configured Ziggrid start command as: #{java_command}"

#configure bluepill template
template "/etc/bluepill/ziggrid.pill" do
  source "bluepill-config.pill.erb"
  owner node[:ziggrid][:user]
  group node[:ziggrid][:group]
  mode 0644
  variables({
    :user            => node[:ziggrid][:user],
    :group           => node[:ziggrid][:group],
    :command         => java_command,
    :workingDir      => "#{deployDir}",
    :appName         => "ziggrid",
    :pidDir          => File.join(deployDir, "pid", "ziggrid.pid")
  })
end

bluepill_service 'ziggrid' do 
  action [:enable, :load, :restart]
end