#
# Cookbook Name:: ziggrid
# Recipe:: zigtaptomq
#
# Copyright (C) 2013 Ziniki Infrastructure Software, LLC.
# 

include_recipe "ziggrid::shared"
include_recipe "rabbitmq"

ruby_block "announce that node is not ready" do
  block do
    node.set['zigtaptomq']['is_node_ready'] = false
    node.save
  end
end

waitForCouchbase()

bluepill_service 'zigtaptomq' do
  action :stop
end

#configure log4j.properties
template File.join(deployDir, "logs", "zigtaptomq-log4j.properties") do
  source "log4j.properties.erb"
  owner node[:zigtaptomq][:user]
  group node[:zigtaptomq][:group]
  mode 0644
  variables({
    :logFile           => File.join(deployDir, "logs", "zigtaptomq.log"),
  })
end

debugArguments = ""
if node[:zigtaptomq][:debug]
  Chef::Log.info "Putting debug arguments into cluster startup command"
  debugArguments = "-Xdebug -Xrunjdwp:server=y,transport=dt_socket,address=4026,suspend=n"
end

java_command_array = [  

  "java",
  "-cp 'libs/*'",
  debugArguments,
  "-Dlog4j.debug",
  "-Dlog4j.configuration=file:#{File.join(deployDir, "logs", "zigtaptomq-log4j.properties")}",
  "org.ziggrid.taptomq.TapToMQ",                         
  node[:zinikicouch][:trailblazer][:is_elastic_ip] ? "http://#{node[:zinikicouch][:trailblazer][:domain_name]}:8091/" : node.run_state['couchbaseMainUrl'],
  "#{node[:zigtaptomq][:couchbase_bucket]}",
  "#{node[:zigtaptomq][:rabbitmq][:url]}",

]

java_command = java_command_array.join(' ')

Chef::Log.info "Configured java command as: #{java_command}"

#configure bluepill template
template "/etc/bluepill/zigtaptomq.pill" do
  source "bluepill-config.pill.erb"
  owner node[:zigtaptomq][:user]
  group node[:zigtaptomq][:group]
  mode 0644
  variables({
    :user            => node[:zigtaptomq][:user],
    :group           => node[:zigtaptomq][:group],
    :command         => java_command,
    :workingDir      => "#{deployDir}",
    :appName         => "zigtaptomq",
    :pidDir          => File.join(deployDir, "pid", "zigtaptomq.pid")
  })
end

bluepill_service 'zigtaptomq' do 
  action [:enable, :load, :restart]
end

ruby_block "announce that node is ready" do
  block do
    node.set['zigtaptomq']['is_node_ready'] = true
    node.save
  end
end